@@ -2,6 +2,7 @@ import subprocess
 from os import environ
 import argparse
 import math
+from socket import gethostname
 
 
 def tcpb_spawn():
@@ -44,9 +45,12 @@ def _tcpb_spawn(args):
     print(
         f"{total-len(occupied)} out of {total} GPU(s) are available; taking {len(l)} GPU(s)"
     )
+    host = gethostname()
     for i in l:
+        tmplog = f"tcpb-grain-{host}-device{i}.log"
         p = subprocess.Popen(
-            ["grain", "up"],
+            f"grain up &> {tmplog} && rm -f {tmplog}",
+            shell=True,
             env=environ | dict(CUDA_VISIBLE_DEVICES=str(i)),
             start_new_session=True,
             stdout=subprocess.DEVNULL,
